@@ -64,7 +64,7 @@ class User(Base):
     username = Column(String(32), unique=True, nullable = False)
     password = Column(String(32))
     active = Column(Boolean)
-    email = Column(String(64))
+    email = Column(String(64), unique=True, nullable=True)
     role_id = Column(Integer, ForeignKey('ab_role.id'))
     role = relationship("Role")
 
