@@ -170,7 +170,7 @@ class UserDBGeneralView(UserGeneralView):
                            title = self.show_title,
                            widgets = widgets,
                            baseapp = self.baseapp,
-                           related_views = self.related_views)
+                           related_views = self._related_views)
 
 
     @expose('/userinfo/')
