@@ -1,10 +1,12 @@
+import logging
 from flask import render_template, flash, redirect, url_for, request, send_file
 from .filemanager import uuid_originalname
 from .security.decorators import has_access
-from .widgets import FormWidget, ListAddWidget
+from .widgets import FormWidget, GroupFormListWidget
 from .actions import action
 from .baseviews import expose, BaseView, BaseCRUDView
 
+log = logging.getLogger(__name__)
 
 class IndexView(BaseView):
     """
@@ -150,7 +152,7 @@ class GeneralView(BaseCRUDView):
                            title = self.show_title,
                            widgets = widgets,
                            baseapp = self.baseapp,
-                           related_views = self.related_views)
+                           related_views = self._related_views)
 
 
     
@@ -188,7 +190,7 @@ class GeneralView(BaseCRUDView):
                         title = self.edit_title,
                         widgets = widgets,
                         baseapp = self.baseapp,
-                        related_views = self.related_views)
+                        related_views = self._related_views)
 
         
 
@@ -222,53 +224,61 @@ class GeneralView(BaseCRUDView):
             flash("Access is Denied %s %s" % (name, self.__class__.__name__),"danger")
             return redirect('.')
         
-    
-class ListAddViewMixin(BaseCRUDView):
+
+class CompactCRUDMixin(BaseCRUDView):
     """
-        Mix with general view to implement a list with add
+        Mix with GeneralView to implement a list with add and edit on the same page.
     """
-    list_widget = ListAddWidget
-    
-    def _get_list_widget(self, filters,
-                        actions = None,
-                        order_column = '', 
-                        order_direction = '',
-                        page = None,
-                        page_size = None,
-                        widgets = {}, **args):
+    _session_form_title = ''
+    _session_form_widget = None
+    _session_form_action = ''
+
+    def _get_list_widget(self, **args):
         """ get joined base filter and current active filter for query """
-        actions = actions or self.actions
-        page_size = page_size or self.page_size
-        if not order_column and self.base_order:
-            order_column, order_direction = self.base_order    
-        joined_filters = filters.get_joined_filters(self._base_filters)
-        count, lst = self.datamodel.query(joined_filters, order_column, order_direction, page=page, page_size=page_size)
-        pks = self.datamodel.get_keys(lst)
-        widgets['list'] = self.list_widget(route_base = self.route_base,
-                                                label_columns = self.label_columns,
-                                                include_columns = self.list_columns,
-                                                value_columns = self.datamodel.get_values(lst, self.list_columns),
-                                                order_columns = self.order_columns,
-                                                page = page,
-                                                page_size = page_size,
-                                                count = count,
-                                                pks = pks,
-                                                actions = actions,
-                                                filters = filters,
-                                                add_widget = self._curr_form_widget,
-                                                generalview_name = self.__class__.__name__
-                                                )
-        return widgets
+        widgets = super(CompactCRUDMixin, self)._get_list_widget(**args)
+        ret_widget = {}
+        ret_widget['list'] = GroupFormListWidget(list_widget=widgets.get('list'), 
+                                    form_widget = self._session_form_widget,
+                                    form_action = self._session_form_action,
+                                    form_title = self._session_form_title)
+        return ret_widget
 
     @expose('/list/', methods=['GET', 'POST'])
     @has_access
     def list(self):
-
         list_widgets = self._list()
-        self._curr_form_widget = self._add()
-        if not self._curr_form_widget:
-            return redirect(self._get_redirect())
         return render_template(self.list_template,
                                         title = self.list_title,
                                         widgets = list_widgets,
                                         baseapp = self.baseapp)
+
+    @expose('/add/', methods=['GET', 'POST'])
+    @has_access
+    def add(self):
+        widgets = self._add()
+        if not widgets:
+            self._session_form_action = ''
+            self._session_form_widget = None
+            return redirect(request.referrer)
+        else:
+            self._session_form_widget = widgets.get('add')
+            self._session_form_action = request.url
+            self._session_form_title = self.add_title
+            return redirect(self._get_redirect())
+
+
+    @expose('/edit/<pk>', methods=['GET', 'POST'])
+    @has_access
+    def edit(self, pk):
+        widgets = self._edit(pk)
+        if not widgets:
+            self._session_form_action = ''
+            self._session_form_widget = None
+            
+            return redirect(self._get_redirect())
+        else:
+            self._session_form_widget = widgets.get('edit')
+            self._session_form_action = request.url
+            self._session_form_title = self.edit_title
+            return redirect(self._get_redirect())
+            
